agentle.mcp.resources.resource\_description
===========================================

.. automodule:: agentle.mcp.resources.resource_description

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      ResourceDescription
   